@@ -1,14 +1,9 @@
 package Tapper::TAP::Harness;
-# git description: v4.1.0-1-g7bc34da
-
 BEGIN {
   $Tapper::TAP::Harness::AUTHORITY = 'cpan:TAPPER';
 }
-{
-  $Tapper::TAP::Harness::VERSION = '4.1.1';
-}
 # ABSTRACT: Tapper - Tapper specific TAP handling
-
+$Tapper::TAP::Harness::VERSION = '4.1.2';
 use 5.010;
 use strict;
 use warnings;
@@ -70,9 +65,9 @@ has parsed_report  => ( is => 'rw', isa => 'HashRef', default => sub {{}} );
 has section_names  => ( is => 'rw', isa => 'HashRef', default => sub {{}} );
 
 our $re_prove_section          = qr/^([-_\d\w\/.]*\w)\s?\.{2,}\s*$/;
-our $re_tapper_meta           = qr/^#\s*((?:Tapper|Artemis)-)([-\w]+):(.+)$/i;
-our $re_tapper_meta_section   = qr/^#\s*((?:Tapper|Artemis)-Section:)\s*(.+)$/i;
-our $re_explicit_section_start = qr/^#\s*((?:Tapper|Artemis)-explicit-section-start:)\s*(\S*)/i;
+our $re_tapper_meta           = qr/^#\s*((?:Tapper|Artemis|Test)-)([-\w]+):(.+)$/i;
+our $re_tapper_meta_section   = qr/^#\s*((?:Tapper|Artemis|Test)-Section:)\s*(.+)$/i;
+our $re_explicit_section_start = qr/^#\s*((?:Tapper|Artemis|Test)-explicit-section-start:)\s*(\S*)/i;
 
 sub _get_prove {
         my $prove = $^X;
@@ -345,10 +340,10 @@ sub _parse_tap_into_sections_archive
                                 $section{raw} .= "$raw\n";
                         }
 
-                        my $re_tapper_meta           = qr/^#\s*((?:Tapper|Artemis)-)([-\w]+):(.+)$/i;
-                        my $re_tapper_meta_section   = qr/^#\s*((?:Tapper|Artemis)-Section:)\s*(.+)$/i;
+                        my $re_tapper_meta           = qr/^#\s*((?:Tapper|Artemis|Test)-)([-\w]+):(.+)$/i;
+                        my $re_tapper_meta_section   = qr/^#\s*((?:Tapper|Artemis|Test)-Section:)\s*(.+)$/i;
                         # looks like tapper meta line
-                        if ( $line->is_comment and $raw =~ m/^#\s*((?:Tapper|Artemis)-)([-\w]+):(.+)$/i ) # (
+                        if ( $line->is_comment and $raw =~ m/^#\s*((?:Tapper|Artemis|Test)-)([-\w]+):(.+)$/i ) # (
                         {
                                 # TODO: refactor inner part with _parse_tap_into_sections_raw()
                                 my $key = lc $2;
@@ -575,6 +570,7 @@ sub generate_html
 1; # End of Tapper::TAP::Harness
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -608,11 +604,10 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
